#### Script for Demographic Research Article
#### Title: Educational assortative mating and the decline of hypergamy in 27 European countries. 
#### An examination of trends through cohorts.
#### Be sure to read the attached readme file for further details

#### General notes:
## Data source - European Social Survey, waves 1-9.
## All data is weighted according to the ESS guidelines.
## Script heavily relies on the tidyverse packages by Wickham et al. (2019). 
## https://doi.org/10.21105/joss.01686
## Note: script might take a while to run, caused by weighting and bootstrapping (about 3-4 minutes)

#### Setting up packages, directories

install.packages(c("readr", "tidyverse", "srvyr", "ggpubr", "wBoot"))

library(readr)                              # For data importing
library(tidyverse)                          # For general wrangling and visualization
library(srvyr)                              # For survey weighting
library(ggpubr)                             # For plot arrangement
library(wBoot)                              # For bootstrapped correlation statistics


options(scipen=999)                         # Disable scientific notation. To enable, set options(scipen=0).
dir.create("d:/ESS")                        # IMPORTANT: Before proceeding, place all unpacked data files into this newly created folder !!!!
setwd("d:/ESS")                             # Assign ESS as working directory

#### Getting the data

ess_db <- read_csv("ess_db.csv")            # Load main attached database
ess_db$X1 <- NULL                           # Ignore useless first row

# Calculate new weight for pooled "Europe" data

ess_db$eurweight <- ess_db$pspwght*ess_db$pweight # This enables the assessment of pooled data with population size correction (based on ESS 2014 guidelines)

# Split database for analysis

ESS_f <- select(ess_db, cntry, eurweight, pspwght, gndr, yrbrn, agea, edulvla)           # Data for F-index
ESS_h <- select(ess_db, cntry, eurweight, pspwght, gndr, yrbrn, agea, edulvla, edulvlpa) # Data for H-index

#### F-index calculations for all 27 nations
# Individual countries: need post-stratification (pspwght) weighting
# Ages of 25-55 needed to include people with non-changing education levels and limit education and cohort-specific biases
# Omitted: no education, gender, birth or age data, or low response countries
# Labels are assigned in the script, and the standard error of the weighting is deleted
# New cohort and education variables are created, see details in paper
# Data is then converted into a wide format
# Followed by creating the needed totals and proportions for F-index calculations
 
f_data <- ESS_f %>%
  as_survey(weights = pspwght) %>%
  filter(agea >= 25 & agea <= 55) %>%                                                
  filter(gndr == "1" | gndr == "2") %>%
  filter(!(cntry == "IS" | cntry == "TR" | 
           cntry == "IL" | cntry == "HR" |           
           cntry == "LU" | cntry == "ME" | 
           cntry == "LV" | cntry == "RS")) %>%
  filter(!(edulvla == "55" | edulvla == "77" | edulvla == "88" | edulvla == "99")) %>% 
  filter(!(yrbrn == "6666" | yrbrn == "7777" | yrbrn == "8888" | yrbrn == "9999")) %>% 
  filter(!(is.na(yrbrn))) %>%                                                         
  filter(!(is.na(gndr))) %>%
  filter(!(is.na(edulvla))) %>%
  filter(!(is.na(agea))) %>%
  mutate(education = factor(edulvla, levels = c(1,2,3,4,5), ordered = T)) %>%         
  mutate(education_tc = fct_collapse(education,
                                     Low = c("1", "2"),
                                     Middle = c("3","4"),
                                     High = c("5"))) %>%
  mutate(yearborn = as.numeric(yrbrn)) %>%
  mutate(cohort = case_when(yearborn >= 1900 & yearborn <= 1954 ~ "-1954",
                            yearborn >= 1955 & yearborn <= 1959 ~ "1955-1959",
                            yearborn >= 1960 & yearborn <= 1964 ~ "1960-1964",
                            yearborn >= 1965 & yearborn <= 1969 ~ "1965-1969",
                            yearborn >= 1970 & yearborn <= 1974 ~ "1970-1974",
                            yearborn >= 1975 & yearborn <= 1979 ~ "1975-1979",
                            yearborn >= 1980 & yearborn <= 2100 ~ "1980-")) %>%
  mutate(gndr = factor(gndr, levels = c(1,2), labels = c("Male","Female"))) %>%       
  group_by(cntry, cohort, education_tc, gndr) %>%
  summarize(number = survey_total()) %>%
  mutate(number = round(x = number, digits = 0)) %>%                                  
  select(-number_se) %>%
  pivot_wider(id_cols = c(cntry, cohort),
              names_from = c(education_tc,gndr),
              values_from = number) %>%                                                              
  mutate(Total_Male = Low_Male + Middle_Male + High_Male) %>%                         
  mutate(Total_Female = Low_Female + Middle_Female + High_Female) %>%                 
  mutate(LoMalP = Low_Male / Total_Male) %>%                                          
  mutate(MidMalP = Middle_Male / Total_Male) %>%
  mutate(HighMalP = High_Male / Total_Male) %>%
  mutate(LoFemP = Low_Female / Total_Female) %>%
  mutate(MidFemP = Middle_Female / Total_Female) %>%
  mutate(HighFemP = High_Female / Total_Female)

# Creating the F-index

f_data$ftop <- f_data$HighFemP * (f_data$LoMalP + f_data$MidMalP) + f_data$MidFemP * f_data$LoMalP
f_data$fbot <- 1 - (f_data$LoFemP * f_data$LoMalP + f_data$MidFemP * f_data$MidMalP + f_data$HighFemP * f_data$HighMalP)
f_data$Findex <- f_data$ftop/f_data$fbot
f_data$ftop <- NULL
f_data$fbot <- NULL

# Creating a tertiary difference variable

f_data$diff <- (f_data$HighFemP - f_data$HighMalP) * 100

# Creating database with all needed variables

db_drart <- select(f_data, cohort, cntry, diff, Findex, Total_Male, Total_Female)

#### F-index calculations for the pooled sample
# A combination of stratification weights (pspwght) and population weights (pweight) is needed
# Ages of 25-55 needed to include people with non-changing education levels and limit education and cohort-specific biases
# Omitted: no education, gender, birth or age data, or low response countries
# Labels are assigned in the script, and the standard error of the weighting is deleted
# New cohort and education variables are created, see details in paper
# Data is then converted into a wide format
# Followed by creating the needed totals and proportions for F-index calculations

f_dataeur <- ESS_f %>%
  as_survey(weights = eurweight) %>%
  filter(agea >= 25 & agea <= 55) %>%                                                
  filter(gndr == "1" | gndr == "2") %>%
  filter(!(cntry == "IS" | cntry == "TR" | 
           cntry == "IL" | cntry == "HR" |           
           cntry == "LU" | cntry == "ME" | 
           cntry == "LV" | cntry == "RS")) %>%
  filter(!(edulvla == "55" | edulvla == "77" | edulvla == "88" | edulvla == "99")) %>% 
  filter(!(yrbrn == "6666" | yrbrn == "7777" | yrbrn == "8888" | yrbrn == "9999")) %>% 
  filter(!(is.na(yrbrn))) %>%                                                         
  filter(!(is.na(gndr))) %>%
  filter(!(is.na(edulvla))) %>%
  filter(!(is.na(agea))) %>%
  mutate(education = factor(edulvla, levels = c(1,2,3,4,5), ordered = T)) %>%         
  mutate(education_tc = fct_collapse(education,
                                     Low = c("1", "2"),
                                     Middle = c("3","4"),
                                     High = c("5"))) %>%
  mutate(yearborn = as.numeric(yrbrn)) %>%
  mutate(cohort = case_when(yearborn >= 1900 & yearborn <= 1954 ~ "-1954",
                            yearborn >= 1955 & yearborn <= 1959 ~ "1955-1959",
                            yearborn >= 1960 & yearborn <= 1964 ~ "1960-1964",
                            yearborn >= 1965 & yearborn <= 1969 ~ "1965-1969",
                            yearborn >= 1970 & yearborn <= 1974 ~ "1970-1974",
                            yearborn >= 1975 & yearborn <= 1979 ~ "1975-1979",
                            yearborn >= 1980 & yearborn <= 2100 ~ "1980-")) %>%
  mutate(gndr = factor(gndr, levels = c(1,2), labels = c("Male","Female"))) %>%       
  group_by(cohort, education_tc, gndr) %>%
  summarize(number = survey_total()) %>%
  mutate(number = round(x = number, digits = 0)) %>%                                  
  select(-number_se) %>%
  pivot_wider(id_cols = c(cohort),
              names_from = c(education_tc,gndr),
              values_from = number) %>%                                                              
  mutate(Total_Male = Low_Male + Middle_Male + High_Male) %>%                         
  mutate(Total_Female = Low_Female + Middle_Female + High_Female) %>%                 
  mutate(LoMalP = Low_Male / Total_Male) %>%                                          
  mutate(MidMalP = Middle_Male / Total_Male) %>%
  mutate(HighMalP = High_Male / Total_Male) %>%
  mutate(LoFemP = Low_Female / Total_Female) %>%
  mutate(MidFemP = Middle_Female / Total_Female) %>%
  mutate(HighFemP = High_Female / Total_Female)

# Creating the F-index for pooled

f_dataeur$ftop <- f_dataeur$HighFemP * (f_dataeur$LoMalP + f_dataeur$MidMalP) + f_dataeur$MidFemP * f_dataeur$LoMalP
f_dataeur$fbot <- 1 - (f_dataeur$LoFemP * f_dataeur$LoMalP + f_dataeur$MidFemP * f_dataeur$MidMalP + f_dataeur$HighFemP * f_dataeur$HighMalP)
f_dataeur$Findex <- f_dataeur$ftop/f_dataeur$fbot
f_dataeur$ftop <- NULL
f_dataeur$fbot <- NULL

# Creating tertiary difference variable for pooled

f_dataeur$diff <- (f_dataeur$HighFemP - f_dataeur$HighMalP) * 100

# Creating database with all needed variables for pooled

f_dataeur$cntry <- "EUR"
db_drarteur <- select(f_dataeur, cohort, cntry, diff, Findex, Total_Male, Total_Female)

#### Merging all F-index and tertiary difference data into one

finaldata <- rbind(db_drart, db_drarteur)

#### H-index calculations for all 27 nations
# Individual countries: need post-stratification (pspwght) weighting
# Ages of 25-55 needed to include people with non-changing education levels and limit education and cohort-specific biases
# Omitted: no education, partner education, gender, birth or age data, or low response countries
# Labels are assigned in the script, and the standard error of the weighting is deleted
# New cohort and education variables are created, see details in paper
# Data is then converted into a wide format
# Followed by creating the needed totals and proportions for H-index calculations
# Analysis is done separately for the two genders

hdata1fem <- ESS_h %>%
  as_survey(weights = pspwght) %>%                                                    
  filter(!(is.na(yrbrn))) %>%                                                         
  filter(!(is.na(edulvla))) %>%
  filter(!(is.na(edulvlpa))) %>%                                                      
  filter(!(is.na(agea))) %>%
  filter(gndr == "2") %>%                                                             
  filter(agea >= 25 & agea <= 55) %>%
  filter(!(cntry == "IS" | cntry == "TR" | 
           cntry == "IL" | cntry == "HR" |             
           cntry == "LU" | cntry == "ME" | 
           cntry == "LV" | cntry == "RS")) %>%
  filter(!(edulvla == "55" | edulvla == "77" | edulvla == "88" | edulvla == "99")) %>%
  filter(!(edulvlpa == "55" | edulvlpa == "77" | edulvlpa == "88" | edulvlpa == "99" | edulvlpa == "66" | edulvlpa == "0")) %>%
  filter(!(yrbrn == "6666" | yrbrn == "7777" | yrbrn == "8888" | yrbrn == "9999")) %>%
  mutate(education = factor(edulvla, levels = c(1,2,3,4,5), ordered = T)) %>%
  mutate(eduresp = fct_collapse(education,                                            
                                Low = c("1", "2"),
                                Middle = c("3","4"),
                                High = c("5"))) %>%
  mutate(educationp = factor(edulvlpa, levels = c(1,2,3,4,5), ordered = T)) %>%       
  mutate(edupart = fct_collapse(educationp,
                                Low = c("1", "2"),
                                Middle = c("3","4"),
                                High = c("5"))) %>%
  mutate(yearborn = as.numeric(yrbrn)) %>%                                            
  mutate(cohort = case_when(yearborn >= 1900 & yearborn <= 1954 ~ "-1954",
                            yearborn >= 1955 & yearborn <= 1959 ~ "1955-1959",
                            yearborn >= 1960 & yearborn <= 1964 ~ "1960-1964",
                            yearborn >= 1965 & yearborn <= 1969 ~ "1965-1969",
                            yearborn >= 1970 & yearborn <= 1974 ~ "1970-1974",
                            yearborn >= 1975 & yearborn <= 1979 ~ "1975-1979",
                            yearborn >= 1980 & yearborn <= 2100 ~ "1980-")) %>%
  mutate(relstr = case_when(eduresp == "Low" & edupart == "Low" ~ "1",                
                            eduresp == "Middle" & edupart == "Middle" ~ "1",
                            eduresp == "High" & edupart == "High" ~ "1",
                            eduresp == "Low" & edupart == "Middle" ~ "2",
                            eduresp == "Low" & edupart == "High" ~ "2",
                            eduresp == "Middle" & edupart == "Low" ~ "3",
                            eduresp == "Middle" & edupart == "High" ~ "2",
                            eduresp == "High" & edupart == "Low" ~ "3",
                            eduresp == "High" & edupart == "Middle" ~ "3")) %>%
  mutate(relstr = factor(relstr, level = c(1,2,3), labels = c("FHomogamy", "FFlM", "FFhM"))) %>%
  group_by(cntry, cohort, relstr) %>%
  summarize(number = survey_total()) %>%
  mutate(number = round(x = number, digits = 0)) %>%                                  
  select(-number_se) %>%
  pivot_wider(id_cols = c(cntry, cohort),
              names_from = c(relstr),
              values_from = number) 

hdata1mal <- ESS_h %>%                                                                
  as_survey(weights = pspwght) %>%
  filter(!(is.na(yrbrn))) %>%
  filter(!(is.na(edulvla))) %>%
  filter(!(is.na(edulvlpa))) %>%
  filter(!(is.na(agea))) %>%
  filter(gndr == "1") %>%
  filter(agea >= 25 & agea <= 55) %>%
  filter(!(cntry == "IS" | cntry == "TR" |
           cntry == "IL" | cntry == "HR" |
           cntry == "LU" | cntry == "ME" | 
           cntry == "LV" | cntry == "RS")) %>%
  filter(!(edulvla == "55" | edulvla == "77" | edulvla == "88" | edulvla == "99")) %>%
  filter(!(edulvlpa == "55" | edulvlpa == "77" | edulvlpa == "88" | edulvlpa == "99" | edulvlpa == "66" | edulvlpa == "0")) %>%
  filter(!(yrbrn == "6666" | yrbrn == "7777" | yrbrn == "8888" | yrbrn == "9999")) %>%
  mutate(education = factor(edulvla, levels = c(1,2,3,4,5), ordered = T)) %>%
  mutate(eduresp = fct_collapse(education,
                                Low = c("1", "2"),
                                Middle = c("3","4"),
                                High = c("5"))) %>%
  mutate(educationp = factor(edulvlpa, levels = c(1,2,3,4,5), ordered = T)) %>%
  mutate(edupart = fct_collapse(educationp,
                                Low = c("1", "2"),
                                Middle = c("3","4"),
                                High = c("5"))) %>%
  mutate(yearborn = as.numeric(yrbrn)) %>%
  mutate(cohort = case_when(yearborn >= 1900 & yearborn <= 1954 ~ "-1954",
                            yearborn >= 1955 & yearborn <= 1959 ~ "1955-1959",
                            yearborn >= 1960 & yearborn <= 1964 ~ "1960-1964",
                            yearborn >= 1965 & yearborn <= 1969 ~ "1965-1969",
                            yearborn >= 1970 & yearborn <= 1974 ~ "1970-1974",
                            yearborn >= 1975 & yearborn <= 1979 ~ "1975-1979",
                            yearborn >= 1980 & yearborn <= 2100 ~ "1980-")) %>%
  mutate(relstr = case_when(eduresp == "Low" & edupart == "Low" ~ "1",
                            eduresp == "Middle" & edupart == "Middle" ~ "1",
                            eduresp == "High" & edupart == "High" ~ "1",
                            eduresp == "Low" & edupart == "Middle" ~ "3",
                            eduresp == "Low" & edupart == "High" ~ "3",
                            eduresp == "Middle" & edupart == "Low" ~ "2",
                            eduresp == "Middle" & edupart == "High" ~ "3",
                            eduresp == "High" & edupart == "Low" ~ "2",
                            eduresp == "High" & edupart == "Middle" ~ "2")) %>%
  mutate(relstr = factor(relstr, level = c(1,2,3), labels = c("MHomogamy", "MFlM", "MFhM"))) %>%
  group_by(cntry, cohort, relstr) %>%
  summarize(number = survey_total()) %>%
  mutate(number = round(x = number, digits = 0)) %>%
  select(-number_se) %>%
  pivot_wider(id_cols = c(cntry, cohort),
              names_from = c(relstr),
              values_from = number)

# Join the data and create H-index

hdata1 <- left_join(x = hdata1fem, y = hdata1mal, by = c("cntry", "cohort")) %>%
  mutate(Homogamy = FHomogamy+MHomogamy) %>%
  mutate(Hypergamy = FFlM + MFlM) %>%
  mutate(Hypogamy = FFhM + MFhM) %>%
  mutate(Hindex = log(Hypergamy / Hypogamy))

#### H-index calculations for the pooled sample
# A combination of stratification weights (pspwght) and population weights (pweight) is needed
# Ages of 25-55 needed to include people with non-changing education levels and limit education and cohort-specific biases
# Omitted: no education, partner education, gender, birth or age data, or low response countries
# Labels are assigned in the script, and the standard error of the weighting is deleted
# New cohort and education variables are created, see details in paper
# Data is then converted into a wide format
# Followed by creating the needed totals and proportions for H-index calculations
# Analysis is done separately for the genders

hdata1femeur <- ESS_h %>%
  as_survey(weights = eurweight) %>%                                                    
  filter(!(is.na(yrbrn))) %>%                                                         
  filter(!(is.na(edulvla))) %>%
  filter(!(is.na(edulvlpa))) %>%                                                      
  filter(!(is.na(agea))) %>%
  filter(gndr == "2") %>%                                                             
  filter(agea >= 25 & agea <= 55) %>%
  filter(!(cntry == "IS" | cntry == "TR" | 
             cntry == "IL" | cntry == "HR" |             
             cntry == "LU" | cntry == "ME" | 
             cntry == "LV" | cntry == "RS")) %>%
  filter(!(edulvla == "55" | edulvla == "77" | edulvla == "88" | edulvla == "99")) %>%
  filter(!(edulvlpa == "55" | edulvlpa == "77" | edulvlpa == "88" | edulvlpa == "99" | edulvlpa == "66" | edulvlpa == "0")) %>%
  filter(!(yrbrn == "6666" | yrbrn == "7777" | yrbrn == "8888" | yrbrn == "9999")) %>%
  mutate(education = factor(edulvla, levels = c(1,2,3,4,5), ordered = T)) %>%
  mutate(eduresp = fct_collapse(education,                                            
                                Low = c("1", "2"),
                                Middle = c("3","4"),
                                High = c("5"))) %>%
  mutate(educationp = factor(edulvlpa, levels = c(1,2,3,4,5), ordered = T)) %>%       
  mutate(edupart = fct_collapse(educationp,
                                Low = c("1", "2"),
                                Middle = c("3","4"),
                                High = c("5"))) %>%
  mutate(yearborn = as.numeric(yrbrn)) %>%                                            
  mutate(cohort = case_when(yearborn >= 1900 & yearborn <= 1954 ~ "-1954",
                            yearborn >= 1955 & yearborn <= 1959 ~ "1955-1959",
                            yearborn >= 1960 & yearborn <= 1964 ~ "1960-1964",
                            yearborn >= 1965 & yearborn <= 1969 ~ "1965-1969",
                            yearborn >= 1970 & yearborn <= 1974 ~ "1970-1974",
                            yearborn >= 1975 & yearborn <= 1979 ~ "1975-1979",
                            yearborn >= 1980 & yearborn <= 2100 ~ "1980-")) %>%
  mutate(relstr = case_when(eduresp == "Low" & edupart == "Low" ~ "1",                
                            eduresp == "Middle" & edupart == "Middle" ~ "1",
                            eduresp == "High" & edupart == "High" ~ "1",
                            eduresp == "Low" & edupart == "Middle" ~ "2",
                            eduresp == "Low" & edupart == "High" ~ "2",
                            eduresp == "Middle" & edupart == "Low" ~ "3",
                            eduresp == "Middle" & edupart == "High" ~ "2",
                            eduresp == "High" & edupart == "Low" ~ "3",
                            eduresp == "High" & edupart == "Middle" ~ "3")) %>%
  mutate(relstr = factor(relstr, level = c(1,2,3), labels = c("FHomogamy", "FFlM", "FFhM"))) %>%
  group_by(cohort, relstr) %>%
  summarize(number = survey_total()) %>%
  mutate(number = round(x = number, digits = 0)) %>%                                  
  select(-number_se) %>%
  pivot_wider(id_cols = c(cohort),
              names_from = c(relstr),
              values_from = number) 

hdata1maleur <- ESS_h %>%                                                                
  as_survey(weights = eurweight) %>%
  filter(!(is.na(yrbrn))) %>%
  filter(!(is.na(edulvla))) %>%
  filter(!(is.na(edulvlpa))) %>%
  filter(!(is.na(agea))) %>%
  filter(gndr == "1") %>%
  filter(agea >= 25 & agea <= 55) %>%
  filter(!(cntry == "IS" | cntry == "TR" |
             cntry == "IL" | cntry == "HR" |
             cntry == "LU" | cntry == "ME" | 
             cntry == "LV" | cntry == "RS")) %>%
  filter(!(edulvla == "55" | edulvla == "77" | edulvla == "88" | edulvla == "99")) %>%
  filter(!(edulvlpa == "55" | edulvlpa == "77" | edulvlpa == "88" | edulvlpa == "99" | edulvlpa == "66" | edulvlpa == "0")) %>%
  filter(!(yrbrn == "6666" | yrbrn == "7777" | yrbrn == "8888" | yrbrn == "9999")) %>%
  mutate(education = factor(edulvla, levels = c(1,2,3,4,5), ordered = T)) %>%
  mutate(eduresp = fct_collapse(education,
                                Low = c("1", "2"),
                                Middle = c("3","4"),
                                High = c("5"))) %>%
  mutate(educationp = factor(edulvlpa, levels = c(1,2,3,4,5), ordered = T)) %>%
  mutate(edupart = fct_collapse(educationp,
                                Low = c("1", "2"),
                                Middle = c("3","4"),
                                High = c("5"))) %>%
  mutate(yearborn = as.numeric(yrbrn)) %>%
  mutate(cohort = case_when(yearborn >= 1900 & yearborn <= 1954 ~ "-1954",
                            yearborn >= 1955 & yearborn <= 1959 ~ "1955-1959",
                            yearborn >= 1960 & yearborn <= 1964 ~ "1960-1964",
                            yearborn >= 1965 & yearborn <= 1969 ~ "1965-1969",
                            yearborn >= 1970 & yearborn <= 1974 ~ "1970-1974",
                            yearborn >= 1975 & yearborn <= 1979 ~ "1975-1979",
                            yearborn >= 1980 & yearborn <= 2100 ~ "1980-")) %>%
  mutate(relstr = case_when(eduresp == "Low" & edupart == "Low" ~ "1",
                            eduresp == "Middle" & edupart == "Middle" ~ "1",
                            eduresp == "High" & edupart == "High" ~ "1",
                            eduresp == "Low" & edupart == "Middle" ~ "3",
                            eduresp == "Low" & edupart == "High" ~ "3",
                            eduresp == "Middle" & edupart == "Low" ~ "2",
                            eduresp == "Middle" & edupart == "High" ~ "3",
                            eduresp == "High" & edupart == "Low" ~ "2",
                            eduresp == "High" & edupart == "Middle" ~ "2")) %>%
  mutate(relstr = factor(relstr, level = c(1,2,3), labels = c("MHomogamy", "MFlM", "MFhM"))) %>%
  group_by(cohort, relstr) %>%
  summarize(number = survey_total()) %>%
  mutate(number = round(x = number, digits = 0)) %>%
  select(-number_se) %>%
  pivot_wider(id_cols = c(cohort),
              names_from = c(relstr),
              values_from = number)

# Join data and create H-index for pooled

hdata1eur <- left_join(x = hdata1femeur, y = hdata1maleur, by = c("cohort")) %>%
  mutate(Homogamy = FHomogamy+MHomogamy) %>%
  mutate(Hypergamy = FFlM + MFlM) %>%
  mutate(Hypogamy = FFhM + MFhM) %>%
  mutate(Hindex = log(Hypergamy / Hypogamy))
hdata1eur$cntry <- "EUR"

# Merge H-index databases

hdata2 <- rbind(hdata1, hdata1eur)
finaldatah <- select(hdata2, cntry, cohort, Homogamy, Hypergamy, Hypogamy, Hindex)

#### Create final database for analyses and clear memory

drdb_ess <- merge(finaldata, finaldatah, by = c("cohort", "cntry"))
rm(list=setdiff(ls(), "drdb_ess"))

#### Assign full country names - this is optional for some graphs

drdb_ess$cntryl[drdb_ess$cntry == "AT"] <- "Austria"                                    
drdb_ess$cntryl[drdb_ess$cntry == "BE"] <- "Belgium"
drdb_ess$cntryl[drdb_ess$cntry == "BG"] <- "Bulgaria"
drdb_ess$cntryl[drdb_ess$cntry == "CH"] <- "Switzerland"
drdb_ess$cntryl[drdb_ess$cntry == "CZ"] <- "Czech Republic"
drdb_ess$cntryl[drdb_ess$cntry == "DE"] <- "Germany"
drdb_ess$cntryl[drdb_ess$cntry == "DK"] <- "Denmark"
drdb_ess$cntryl[drdb_ess$cntry == "EE"] <- "Estonia"
drdb_ess$cntryl[drdb_ess$cntry == "ES"] <- "Spain"
drdb_ess$cntryl[drdb_ess$cntry == "EUR"] <- "Europe"
drdb_ess$cntryl[drdb_ess$cntry == "FI"] <- "Finland"
drdb_ess$cntryl[drdb_ess$cntry == "FR"] <- "France"
drdb_ess$cntryl[drdb_ess$cntry == "GB"] <- "United Kingdom"
drdb_ess$cntryl[drdb_ess$cntry == "GR"] <- "Greece"
drdb_ess$cntryl[drdb_ess$cntry == "HU"] <- "Hungary"
drdb_ess$cntryl[drdb_ess$cntry == "IE"] <- "Ireland"
drdb_ess$cntryl[drdb_ess$cntry == "IT"] <- "Italy"
drdb_ess$cntryl[drdb_ess$cntry == "LT"] <- "Lithuania"
drdb_ess$cntryl[drdb_ess$cntry == "NL"] <- "Netherlands"
drdb_ess$cntryl[drdb_ess$cntry == "NO"] <- "Norway"
drdb_ess$cntryl[drdb_ess$cntry == "PL"] <- "Poland"
drdb_ess$cntryl[drdb_ess$cntry == "PT"] <- "Portugal"
drdb_ess$cntryl[drdb_ess$cntry == "RU"] <- "Russia"
drdb_ess$cntryl[drdb_ess$cntry == "SE"] <- "Sweden"
drdb_ess$cntryl[drdb_ess$cntry == "SI"] <- "Slovenia"
drdb_ess$cntryl[drdb_ess$cntry == "SK"] <- "Slovakia"
drdb_ess$cntryl[drdb_ess$cntry == "UA"] <- "Ukraine"
drdb_ess$cntryl[drdb_ess$cntry == "CY"] <- "Cyprus"

#### Export tables for appendix

# Number of respondents: F-index and tertiary difference calculations

nof1 <- select(drdb_ess, cntryl, cohort, Total_Male, Total_Female)
nof1 <- mutate(nof1, respondents = Total_Male + Total_Female)
nof1$Total_Male <- NULL
nof1$Total_Female <- NULL
nof2 <- pivot_wider(nof1, id_cols = cntryl, names_from = cohort, values_from = respondents)
nof2 <- rename(nof2, Country = cntryl)
write.csv(nof2, "respondents_f_tert.csv")

# Number of respondents: H-index calculations

noh1 <- select(drdb_ess, cntryl, cohort, Homogamy, Hypergamy, Hypogamy)
noh1 <- mutate(noh1, respondents = Homogamy + Hypergamy + Hypogamy)
noh1$Homogamy <- NULL
noh1$Hypergamy <- NULL
noh1$Hypogamy <- NULL
noh2 <- pivot_wider(noh1, id_cols = cntryl, names_from = cohort, values_from = respondents)
noh2 <- rename(noh2, Country = cntryl)
write.csv(noh2, "respondents_h.csv")

# Tertiary difference table

tdiff1 <- select(drdb_ess, cntryl, cohort, diff)
tdiff2 <- pivot_wider(tdiff1, id_cols = cntryl, names_from = cohort, values_from = diff)
tdiff2 <- rename(tdiff2, Country = cntryl)
write.csv(tdiff2, "tertiary_difference.csv")

# F-index table

find1 <- select(drdb_ess, cntryl, cohort, Findex)
find2 <- pivot_wider(find1, id_cols = cntryl, names_from = cohort, values_from = Findex)
find2 <- rename(find2, Country = cntryl)
write.csv(find2, "findex.csv")


# H-index table

hind1 <- select(drdb_ess, cntryl, cohort, Hindex)
hind2 <- pivot_wider(hind1, id_cols = cntryl, names_from = cohort, values_from = Hindex)
hind2 <- rename(hind2, Country = cntryl)
write.csv(hind2, "hindex.csv")

# Clear memory

rm(list=setdiff(ls(), "drdb_ess"))

#### Visualization

# Assigning facet groups to countries - in alphabetic order
# The facet groups do not reflect any difference between the groups
# The script automatically saves graphs in the size specified by Demographic Research
# Feel free to adjust DPI to achieve desired file size (do not go below 300)
# Note: picture quality may be automatically decreased by certain text and image processing programs 

drdb_ess <- mutate(drdb_ess, facetg = case_when(cntryl == "Austria" ~ 1,
                                      cntryl == "Belgium" ~ 1,
                                      cntryl == "Bulgaria" ~ 1,
                                      cntryl == "Cyprus" ~ 1,
                                      cntryl == "Czech Republic" ~ 1,
                                      cntryl == "Denmark" ~ 1,
                                      cntryl == "Estonia" ~ 1,
                                      cntryl == "Europe" ~ 1,
                                      cntryl == "Finland" ~ 1,
                                      cntryl == "France" ~ 1,
                                      cntryl == "Germany" ~ 1,
                                      cntryl == "Greece" ~ 1,
                                      cntryl == "Hungary" ~ 1,
                                      cntryl == "Ireland" ~ 1))
drdb_ess$facetg[is.na(drdb_ess$facetg)] <- 2

# Creating individual colours for all countries in both facets
# Colour palette source inspired by: http://medialab.github.io/iwanthue/
# Check them out!

colours_facetg1 <- c("#5de2c8", "#d55692", "#76d881", "#9d6ac9", "#7b9532",
                     "#5177d9", "#af8723", "#5493ed", "#ddb556", "#7884c9",
                     "#d0db7c", "#dd87d8", "#529354", "#d65e5e")
colours_facetg2 <- c("#5acbdc", "#c86f38", "#69b3e5", "#968347", "#c8a9e6",
                     "#a3d79f", "#9471aa", "#409c84", "#af6389", "#e6ad7f",
                     "#4184b5", "#b8715e", "#e591ab", "#d9a176")

## Graph 1: Tertiary difference in 27 European nations and pooled Europe sample

t1 <- ggplot(subset(drdb_ess, facetg == 1), aes(x = cohort, y = diff, group = 1)) +
  facet_wrap(. ~ cntryl, ncol = 2) +
  geom_line(size = 0.45, aes(colour = cntryl)) + 
  geom_hline(yintercept = 0, size = 0.25, colour = "black", linetype = "dotted") +
  theme_minimal(base_size = 8) + 
  scale_colour_manual(values = colours_facetg1) +
  theme(axis.text.x = element_text(size = 6, angle = 90)) +
  theme(axis.text.y = element_text(size = 6)) + 
  theme(strip.text.x = element_text(size = 8)) +
  theme(legend.position = "") + 
  theme(panel.grid.minor = element_blank()) +
  xlab("") +
  ylab("") +
  ylim(-22,22)
t2 <- ggplot(subset(drdb_ess, facetg == 2), aes(x = cohort, y = diff, group = 1)) +
  facet_wrap(. ~ cntryl, ncol = 2) +
  geom_line(size = 0.45, aes(colour = cntryl)) + 
  geom_hline(yintercept = 0, size = 0.25, colour = "black", linetype = "dotted") +
  theme_minimal(base_size = 8) + 
  scale_colour_manual(values = colours_facetg2) +
  theme(axis.text.x = element_text(size = 6, angle = 90)) +
  theme(axis.text.y = element_text(size = 6)) + 
  theme(strip.text.x = element_text(size = 8)) +
  theme(legend.position = "") + 
  theme(panel.grid.minor = element_blank()) +
  xlab("") +
  ylab("") +
  ylim(-22,22)
t3 <- ggarrange(t1, t2, nrow = 1)
t4 <- annotate_figure(t3, left = text_grob("Tertiary difference (%)", size= 8, rot = 90), bottom = text_grob("Cohorts", size = 8)) +
  ggsave(
  "tertiary.jpeg",
  plot = last_plot(),
  device = "jpeg",
  scale = 1,
  width = 12.46,
  height = 14.50,
  units = "cm",
  dpi = 900,
  limitsize = TRUE)
t4

## Graph 2: F-index progression in 27 European nations and pooled Europe sample

f1 <- ggplot(subset(drdb_ess, facetg == 1), aes(x = cohort, y = Findex, group = 1)) +
  facet_wrap(. ~ cntryl, ncol = 2) +
  geom_line(size = 0.45, aes(colour = cntryl)) + 
  geom_hline(yintercept = 0.5, size = 0.25, colour = "black", linetype = "dotted") +
  theme_minimal(base_size = 8) +
  scale_colour_manual(values = colours_facetg1) +
  theme(axis.text.x = element_text(size = 6, angle = 90)) +
  theme(axis.text.y = element_text(size = 6)) + 
  theme(strip.text.x = element_text(size = 8)) +
  theme(legend.position = "") + 
  theme(panel.grid.minor = element_blank()) +
  xlab("") +
  ylab("") +
  ylim(0.25,0.75)
f2 <- ggplot(subset(drdb_ess, facetg == 2), aes(x = cohort, y = Findex, group = 1)) +
  facet_wrap(. ~ cntryl, ncol = 2) +
  geom_line(size = 0.45, aes(colour = cntryl)) + 
  geom_hline(yintercept = 0.5, size = 0.25, colour = "black", linetype = "dotted") +
  theme_minimal(base_size = 8) + 
  scale_colour_manual(values = colours_facetg2) +
  theme(axis.text.x = element_text(size = 6, angle = 90)) +
  theme(axis.text.y = element_text(size = 6)) + 
  theme(strip.text.x = element_text(size = 8)) +
  theme(legend.position = "") + 
  theme(panel.grid.minor = element_blank()) +
  xlab("") +
  ylab("") +
  ylim(0.25,0.75)
f3 <- ggarrange(f1, f2, nrow = 1)
f4 <- annotate_figure(f3, left = text_grob("F-index", size= 8, rot = 90), bottom = text_grob("Cohorts", size = 8)) +
  ggsave(
  "findex.jpeg",
  plot = last_plot(),
  device = "jpeg",
  scale = 1,
  width = 12.46,
  height = 14.50,
  units = "cm",
  dpi = 900,
  limitsize = TRUE)
f4

## Graph 3: H-index progression in 27 European nations and pooled Europe sample

h1 <- ggplot(subset(drdb_ess, facetg == 1), aes(x = cohort, y = Hindex, group = 1)) +
  facet_wrap(. ~ cntryl, ncol = 2) +
  geom_line(size = 0.45, aes(colour = cntryl)) + 
  geom_hline(yintercept = 0, size = 0.25, colour = "black", linetype = "dotted") +
  theme_minimal(base_size = 8) + 
  scale_colour_manual(values = colours_facetg1) +
  theme(axis.text.x = element_text(size = 6, angle = 90)) +
  theme(axis.text.y = element_text(size = 6)) + 
  theme(strip.text.x = element_text(size = 8)) +
  theme(legend.position = "") + 
  theme(panel.grid.minor = element_blank()) +
  xlab("") +
  ylab("") +
  scale_y_continuous(breaks = c(-1.5, -0.75, 0, 0.75, 1.5), limits = c(-1.6,1.6))
h2 <- ggplot(subset(drdb_ess, facetg == 2), aes(x = cohort, y = Hindex, group = 1)) +
  facet_wrap(. ~ cntryl, ncol = 2) +
  geom_line(size = 0.45, aes(colour = cntryl)) + 
  geom_hline(yintercept = 0, size = 0.25, colour = "black", linetype = "dotted") +
  theme_minimal(base_size = 8) + 
  scale_colour_manual(values = colours_facetg2) +
  theme(axis.text.x = element_text(size = 6, angle = 90)) +
  theme(axis.text.y = element_text(size = 6)) + 
  theme(strip.text.x = element_text(size = 8)) +
  theme(legend.position = "") + 
  theme(panel.grid.minor = element_blank()) +
  xlab("") +
  ylab("") +
  scale_y_continuous(breaks = c(-1.5, -0.75, 0, 0.75, 1.5), limits = c(-1.6,1.6))
h3 <- ggarrange(h1, h2, nrow = 1)
h4 <- annotate_figure(h3, left = text_grob("H-index", size= 8, rot = 90), bottom = text_grob("Cohorts", size = 8)) +
  ggsave(
  "hindex.jpeg",
  plot = last_plot(),
  device = "jpeg",
  scale = 1,
  width = 12.46,
  height = 14.50,
  units = "cm",
  dpi = 900,
  limitsize = TRUE)

## Graph 4.: Correlation of F and H in Europe by tertiary difference

# Base correlation

drdb_esscorr <- filter(drdb_ess, cntry != "EUR")
cor.test(drdb_esscorr$Findex, drdb_esscorr$Hindex) # Correlation of F and H for all observations
drdb_esscorr$'Tertiary difference (%)' <- drdb_esscorr$diff # Creating a duplicate of "diff" names properly for plotting

# Bootstrapped correlation (100000)

set.seed(333)
boot.cor.bca(drdb_esscorr$Findex, drdb_esscorr$Hindex, R = 100000)  # BCa method

c2 <- ggplot(drdb_esscorr, aes(x = Findex, y = Hindex, colour = `Tertiary difference (%)`)) + 
  geom_point(size=1) + 
  geom_smooth(method = "lm", se = T, alpha = 0.25, size = 0.40, colour = "black") +
  theme_minimal(base_size = 8) +
  theme(axis.text.x = element_text(size = 6, angle = 0)) +
  theme(axis.text.y = element_text(size = 6)) + 
  theme(strip.text.x = element_text(size = 8)) +
  theme(panel.grid.minor = element_blank()) +
  theme(legend.position = "bottom", legend.box = "horizontal", legend.text = element_text(size = 6)) +
  guides(color = guide_legend(nrow = 1)) +
  labs(x = "F-index", y = "H-index", size = 8) +
  theme(axis.title.x = element_text(vjust= -8)) +
  theme(axis.title.y = element_text(vjust= 3.5)) +
  scale_color_gradient(low = "#450e17", high = "#ffcfd7") +
  scale_y_continuous(breaks = c(-1.5, -0.75, 0, 0.75, 1.5), limits = c(-1.6,1.6)) + 
  scale_x_continuous(breaks = c(0.3, 0.4, 0.5, 0.6, 0.7), limits = c(0.29,0.71)) +
  annotate(geom="text", x=0.56, y=1.4, label="r = -0.88 (-0.91,-0.84) \n p < 0.0001",
           color="black", size = 2.5) +
  ggsave(
  "corr2.jpeg",
  plot = last_plot(),
  device = "jpeg",
  scale = 1,
  width = 12.46,
  height = 14.50,
  units = "cm",
  dpi = 900,
  limitsize = TRUE)
c2

# Graph 5: oldest and youngest cohort progression with area of female advantage

drdb_esscorryoung <- filter(drdb_esscorr, cohort == "1980-")
drdb_esscorrold <- filter(drdb_esscorr, cohort == "-1954")
lithold <- filter(drdb_esscorr, cohort == "1955-1959" & cntry == "LT")
drdb_esscorrold <- rbind(drdb_esscorrold, lithold)

# Base correlations

cor.test(drdb_esscorryoung$Findex, drdb_esscorryoung$Hindex) # Correlation of F and H for youngest cohort
cor.test(drdb_esscorrold$Findex, drdb_esscorrold$Hindex)     # Correlation of F and H for oldest cohort

# Bootstrapped correlation (100000) - young

set.seed(333)
boot.cor.bca(drdb_esscorryoung$Findex, drdb_esscorryoung$Hindex, R = 100000)  # BCa method

# Bootstrapped correlation (100000) - old

set.seed(333)
boot.cor.bca(drdb_esscorrold$Findex, drdb_esscorrold$Hindex, R = 100000)  # BCa method

# Create merged database containing the oldest and youngest cohort only

drdb_esscorrold$cohort <- "Oldest cohort"
drdb_esscorryoung$cohort <- "Youngest cohort"
drdb_esscorrolyg <- rbind(drdb_esscorrold, drdb_esscorryoung)

# Plot young and old data points with fitted lines

cyo1 <- ggplot(drdb_esscorrolyg, aes(x = Findex, y = Hindex, colour = cohort)) + 
  geom_point(size=1) + 
  geom_smooth(method = "lm", se = T, alpha = 0.25, size = 0.40) +
  theme_minimal(base_size = 8) +
  theme(axis.text.x = element_text(size = 6, angle = 0)) +
  theme(axis.text.y = element_text(size = 6)) + 
  theme(strip.text.x = element_text(size = 8)) +
  theme(legend.position = "bottom") + 
  theme(panel.grid.minor = element_blank()) +
  theme(legend.position = "bottom", legend.box = "horizontal", legend.text = element_text(size = 6)) +
  theme(legend.title=element_blank()) +
  labs(x = "F-index", y = "H-index", size = 8) +
  theme(axis.title.x = element_text(vjust= -6)) +
  theme(axis.title.y = element_text(vjust= 3.5)) +
  scale_y_continuous(breaks = c(-1.5, -0.75, 0, 0.75, 1.5), limits = c(-1.6,1.6)) + 
  scale_x_continuous(breaks = c(0.3, 0.4, 0.5, 0.6, 0.7), limits = c(0.29,0.71)) +
  scale_color_manual(values = c("#EF3054", "#1B2F33")) +
  annotate(geom="text", x=0.56, y=1.5, label="r = -0.80 (-0.91,-0.57) \n p < 0.0001",
           color="#EF3054", size = 2.5) +
  annotate(geom="text", x=0.56, y=1.3, label="r = -0.67 (-0.83,-0.42) \n p < 0.0001",
           color="#1B2F33", size = 2.5) +
  geom_hline(yintercept = 0, size = 0.25, colour = "black", linetype = "dotted") +
  geom_vline(xintercept = 0.5, size = 0.25, colour = "black", linetype = "dotted") + 
  geom_text(aes(label=cntry),hjust=-0.3, vjust=0, size = 2.8) +
  geom_rect(aes(xmin = 0.5, xmax = 0.7, ymin = -1.50, ymax = 0.0),
            fill = "blue", inherit.aes=FALSE, alpha = 0.0021) + 
  ggsave(
  "corrygod.jpeg",
  plot = last_plot(),
  device = "jpeg",
  scale = 1,
  width = 12.46,
  height = 14.50,
  units = "cm",
  dpi = 900,
  limitsize = TRUE)
cyo1

